# ReSpotGUI

![](https://raw.githubusercontent.com/digfish/respotgui/master/respotgui.png)

The purpose is to provide a graphical frontend for the [librespot-java](https://github.com/librespot-org/librespot-java), a library that provides streaming and support for Spotify Connect devices. 

# Requirements

- A Spotify premium subscription
- Java installed
- librespot-java (last version can be obtained [here](https://github.com/librespot-org/librespot-java/releases))[^1]
- Python 3 installed (of course!)

# Install

To install type:

```
pip install respotgui
```

to execute:
```
python -m respot.gui
```
or simply:
```
respotgui
```

[^1]: Download the file `librespot-api-*.jar` and execute it with `java -jar`
